@@ -9,7 +9,7 @@ Homepage
 --------
 http://work.thaslwanter.at/sksound/html/
 
-Copyright (c) 2018 Thomas Haslwanter <thomas.haslwanter@fh-linz.at>
+Copyright (c) 2021 Thomas Haslwanter <thomas.haslwanter@fh-linz.at>
 
 '''
 
@@ -17,9 +17,9 @@ import importlib
 
 __author__ = "Thomas Haslwanter <thomas.haslwanter@fh-linz.at"
 __license__ = "BSD 2-Clause License"
-__version__ = "0.2.1"
+__version__ = "0.2.7"
 
-__all__ = ['sounds']
+__all__ = ['misc', 'sounds']
 
 for _m in __all__:
     importlib.import_module('.'+_m, package='sksound')
